//
//  ITXCPlayerAssistor.h
//  TXCPlayerAdapter
//
//  Created by chavezchen on 2021/3/12.
//

#ifndef ITXCPlayerAssistor_h
#define ITXCPlayerAssistor_h

#import "TXCVideoBasicInfo.h"
#import "TXCStreamingInfo.h"
#import "TXCImageSpriteInfo.h"
#import "TXCKeyFrameDescInfo.h"
@protocol ITXCPlayerAssistorProtocol;

typedef void (^ITXCRequestVideoInfoCallback)(id<ITXCPlayerAssistorProtocol> response, NSError *error);

@protocol ITXCPlayerAssistorProtocol <NSObject>

/// 请求视频相关信息接口
- (void)requestVideoInfo:(ITXCRequestVideoInfoCallback)completion;

/// 获取视频基础信息， 必须是在requestVideoInfo:回调之后才生效
- (TXCVideoBasicInfo *)getVideoBasicInfo;

/// 获取视频流信息列表,必须是在requestVideoInfo:回调之后才生效
- (TXCStreamingInfo *)getStreamingInfo;

/// 获取视频关键帧打点信息,必须是在requestVideoInfo:回调之后才生效
- (NSArray<TXCKeyFrameDescInfo *> *)getKeyFrameDescInfos;

/// 获取缩略图信息,必须是在requestVideoInfo:回调之后才生效
- (TXCImageSpriteInfo *)getImageSpriteInfo;

@optional

/** 解密视频数据的解密Token。
 playToken需要在解析完m3u8文件并且下载完成x-key之后才能成功获取
 调用时机：从ts切片的url获取到视频数据后调用。
 解密视频数据方法请关注：TXCDataDecryptor类
 */
- (NSString *)getPlayToken;

@end

#endif /* ITXCPlayerAssistor_h */
