## 1. 集成SDK

### 1.1 前置条件

- **环境要求
  ****需要配置支持http请求，配置方式：在项目的info.plist文件中添加App Transport Security Settings->Allow Arbitrary Loads设置为YES。**

- **组件依赖**

  `GCDWebServer`   

  ```objective-c
  pod "GCDWebServer", "~> 3.0"
  ```

  ### 1.2 集成方式

  #### 1.2.1 手动集成

  

  ## 2. 使用sdk

  #### 初始化Adatper

  **说明**

  初始化Adapter，单例。

  **接口**

  ```
  + (instancetype)shareAdapterWithAppId:(NSUInteger)appId;
  ```

  **参数说明**

  appId：填写 appid（如果使用了子应用，则填 subappid）

  

  #### 销毁Adatper

  **说明**

  销毁Adapter，当程序退出后调用。

  **接口**

  ```
  + (void)destroy;
  ```

  

  #### 创建播放器辅助类

  **说明**

  通过播放器辅助类可以获取播放fileId相关信息以及处理DRM加密接口等。

  **接口**

  ```
  + (id<ITXCPlayerAssistorProtocol>)createPlayerAssistorWithFileId:(NSString *)fileId
                                                             pSign:(NSString *)pSign;
  ```

  **参数说明**

  | 参数名 | 类型   | 描述               |
  | :----- | :----- | :----------------- |
  | fileId | String | 要播放的视频fileId |
  | pSign  | String | 超级播放器签名     |

  #### 请求视频播放信息

  **说明**

  本接口会请求腾讯云点播服务器，获取播放视频的流信息等。

  **接口**

  ```objective-c
  - (void)requestVideoInfo:(ITXCRequestVideoInfoCallback)completion;
  ```

  **参数说明**

  | 参数名         | 类型                         | 描述         |
  | :------------- | :--------------------------- | :----------- |
  | **completion** | ITXCRequestVideoInfoCallback | 异步回调函数 |

  

  销毁播放器辅助类

  **说明**

  销毁辅助类，在退出播放器或者切换了下一个视频播放的时候调用。

  **接口**

  ```
  + (void)destroyPlayerAssistor:(id<ITXCPlayerAssistorProtocol>)assistor;
  ```

  

  #### 获取视频的基本信息

  **说明**

  获取视频信息， 必须是在id<ITXCPlayerAssistorProtocol>.requestVideoInfo回调之后才生效。

  **接口**

  ```
  - (TXCVideoBasicInfo *)getVideoBasicInfo;
  ```

  **参数说明**

  TXCVideoBasicInfo：参数如下

  | 参数名      | 类型   | 描述                   |
  | :---------- | :----- | :--------------------- |
  | name        | String | 视频名称。             |
  | size        | Int    | 视频大小，单位：字节。 |
  | duration    | Float  | 视频时长，单位：秒。   |
  | description | String | 视频描述。             |
  | coverUrl    | String | 视频封面。             |

  

  #### 获取视频流信息

  **说明**

  获取视频流信息列表，必须是在id<ITXCPlayerAssistorProtocol>.requestVideoInfo回调之后才生效。

  **接口**

  ```
  - (TXCStreamingInfo *)getStreamingInfo;
  ```

  **参数说明**

  TXCStreamingInfo

  | 参数名     | 类型   | 描述                                          |
  | :--------- | :----- | :-------------------------------------------- |
  | playUrl    | String | 播放 URL。                                    |
  | subStreams | List   | 自适应码流子流信息，类型为 TXCSubStreamInfo。 |

  TXCSubStreamInfo

  | 参数名         | 类型   | 描述                                   |
  | :------------- | :----- | :------------------------------------- |
  | type           | String | 子流的类型，目前可能的取值仅有 video。 |
  | width          | Int    | 子流视频的宽，单位：px。               |
  | height         | Int    | 子流视频的高，单位：px。               |
  | resolutionName | String | 子流视频在播放器中展示的规格名。       |

  #### 获取关键帧打点信息

  **说明**

  获取视频关键帧打点信息，必须是在id<ITXCPlayerAssistorProtocol>.requestVideoInfo回调之后才生效。

  **接口**

  ```
  - (NSArray<TXCKeyFrameDescInfo *> *)getKeyFrameDescInfos;
  ```

  **参数说明**

  TXCKeyFrameDescInfo

  | 参数名     | 类型   | 描述          |
  | :--------- | :----- | :------------ |
  | timeOffset | Float  | 1.1           |
  | content    | String | "片头开始..." |

  

  #### 获取缩略图信息

  **说明**

  获取缩略图信息，必须是在id<ITXCPlayerAssistorProtocol>.requestVideoInfo回调之后才生效。

  **接口**

  ```
  - (TXCImageSpriteInfo *)getImageSpriteInfo;
  ```

  **参数说明**

  TCXImageSpriteInfo

  | 参数名    | 类型   | 描述                                  |
  | :-------- | :----- | :------------------------------------ |
  | imageUrls | List   | 缩略图下载 URL 数组，类型为 String 。 |
  | webVttUrl | String | 缩略图 VTT 文件下载 URL 。            |

  